@@ -57,6 +57,7 @@
 //! | [`uninit`]| [`before_block_exec_invalidate_opt`] ||
 //! | [`regs`]  | [`insn_translate`]      ||
 //! | [`PandaArgs`] | [`insn_exec`] ||
+#![cfg_attr(doc_cfg, feature(doc_cfg))]
 
 /// Raw bindings to the PANDA API
 #[doc(inline)]
@@ -108,6 +109,10 @@ pub mod enums;
 pub mod plugins;
 pub mod taint;
 
+#[cfg_attr(doc_cfg, doc(cfg(feature = "syscall-injection")))]
+#[cfg(feature = "syscall-injection")]
+pub mod syscall_injection;
+
 pub use enums::arch::*;
 
 /// A set of types PANDA frequently requires but have a low likelihood of clashing with
@@ -120,6 +125,7 @@ pub use enums::arch::*;
 /// ```
 pub mod prelude {
     pub use crate::panda_arg::PandaArgs;
+    pub use crate::regs::SyscallPc;
     pub use crate::sys::target_long;
     pub use crate::sys::target_pid_t;
     pub use crate::sys::target_ptr_t;
